@@ -1,13 +1,12 @@
 use {
+    fnv::FnvHashMap,
     lazy_regex::regex,
-    lazy_static::lazy_static,
     rand::{
         rngs::StdRng,
         Rng,
         SeedableRng,
     },
     std::{
-        collections::HashMap,
         net::Ipv6Addr,
         ops::Range,
         str::FromStr,
@@ -24,7 +23,7 @@ pub struct ChangeStats {
 }
 
 pub struct Transformer {
-    repl: HashMap<String, Box<[u8]>>,
+    repl: FnvHashMap<String, Box<[u8]>>,
     rng: StdRng,
     pub stats: ChangeStats,
 }
@@ -123,7 +122,7 @@ impl Transformer {
     }
 
     pub fn transform_all_ip4(&mut self, line: &mut String) {
-        let ranges = regex!(r#"\b(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b"#)
+        let ranges = regex!(r#"\b(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\b"#)
             .find_iter(line)
             .map(|mat| mat.range())
             .collect::<Vec<Range<usize>>>();
